multiformats.multicodec.err
===========================

.. automodule:: multiformats.multicodec.err

MulticodecKeyError
------------------

.. autoclass:: multiformats.multicodec.err.MulticodecKeyError
    :members:

MulticodecValueError
--------------------

.. autoclass:: multiformats.multicodec.err.MulticodecValueError
    :members:
